//+------------------------------------------------------------------------------------------+
//|                                                                                          |
//|                                   SonicR VA Candles.mq4                                  |
//|                                                                                          |
//+------------------------------------------------------------------------------------------+
#property copyright "Copyright  2011 traderathome"
#property link      "email:   traderathome@msn.com"

/*---------------------------------------------------------------------------------------------
Overview:

This indicator uses some code from the acknowledged indicators to color some candles according 
to the SonicR VA indicator volume situations.  It works for bar charts and candle charts.  The 
benefit is, by viewing candles that get re-colored for the special situation volume bars shown 
by the SonicR VA, it is much easier to understand the relationship between the volume and the 
price activity.

The indicator can be turned on/off without having to remove it from the chart, preserving your
chart settings.  You can specify a different bar with for "rising" and for "climax" bars.  And
you can specify wide bars to automatically add width to both types of bars, which is good for 
when you zoom in one step on a chart. You can also change colors.  To make any such changes, 
modify the under the Inputs tab, close the External Inputs window and change the chart TF back 
and forth once.  Your changes are then made and appear under the Colors tab also.  They will be 
permanent for the chart until you make other changes.
                                                                    - Traderathome, 06-01-2011 
-----------------------------------------------------------------------------------------------
Acknowledgements:
BetterVolume.mq4 - for some core coding (BetterVolume_v1.4).

----------------------------------------------------------------------------------------------
Suggested Settings:         White Chart        Black Chart         Function

#property indicator_color1  C'0,0,196'         C'62,158,255'       Rising Volume - Bull
#property indicator_color2  C'0,0,196'         C'62,158,255'       Rising Volume - Bear
#property indicator_color3  C'31,190,79'       Lime                Climax Volume - Bull
#property indicator_color4  C'230,21,63'       Red                 Climax Volume - Bear
#property indicator_width1  2                  2
#property indicator_width2  2                  2
#property indicator_width3  2                  2
#property indicator_width4  2                  2           
 
---------------------------------------------------------------------------------------------*/

//+-------------------------------------------------------------------------------------------+
//| Indicator Global Inputs                                                                   |                                                        
//+-------------------------------------------------------------------------------------------+ 
#property indicator_chart_window
#property indicator_buffers 4

#property indicator_color1 CornflowerBlue        
#property indicator_color2 CornflowerBlue  
#property indicator_color3 Lime    
#property indicator_color4 Red  

#property indicator_width1 2
#property indicator_width2 2
#property indicator_width3 2
#property indicator_width4 2

//global external inputs
extern bool   Indicator_On                    = true;                       
extern int    Volume_Averaging_Period         = 10;
extern double Volume_Over_Average_Factor      = 1.38;
extern int    Volume_Rising_Width             = 2;
extern int    Volume_Climax_Width             = 3; 
extern bool   Show_Wide_Bars                  = false;
extern int    Volume_Analysis_GoBack          = 20;   
extern color  Volume_Rising_Bull              = C'62,158,255';
extern color  Volume_Rising_Bear              = C'62,158,255';
extern color  Volume_Climax_Bull              = Lime;
extern color  Volume_Climax_Bear              = Red;

//global buffers and variables 
bool   FLAG_deinit;  
int    clr,i,j,n,shift1;
double Buffer1[];
double Buffer2[];
double Buffer3[];
double Buffer4[];
double av,Range,Value2,HiValue2,tempv2,open,close;

//+-------------------------------------------------------------------------------------------+
//| Indicator Initialization                                                                  |                                                        
//+-------------------------------------------------------------------------------------------+   
int init()
   {
   FLAG_deinit = false;
   
   if (Show_Wide_Bars)
      {
      Volume_Rising_Width= Volume_Rising_Width + 1;
      Volume_Climax_Width= Volume_Climax_Width + 1;
      }
      
   SetIndexStyle(0,DRAW_HISTOGRAM, 0, Volume_Rising_Width, Volume_Rising_Bull);
   SetIndexBuffer(0, Buffer1);
   SetIndexStyle(1,DRAW_HISTOGRAM, 0, Volume_Rising_Width, Volume_Rising_Bear);   
   SetIndexBuffer(1, Buffer2);  
   SetIndexStyle(2,DRAW_HISTOGRAM, 0, Volume_Climax_Width, Volume_Climax_Bull);  
   SetIndexBuffer(2, Buffer3);
   SetIndexStyle(3,DRAW_HISTOGRAM, 0, Volume_Climax_Width, Volume_Climax_Bear);
   SetIndexBuffer(3, Buffer4);
 
   return(0);
   }
  
//+-------------------------------------------------------------------------------------------+
//| Indicator De-initialization                                                               |                                                        
//+-------------------------------------------------------------------------------------------+ 
int deinit()
   {   
   return(0);   
   }
  
//+-------------------------------------------------------------------------------------------+
//| Indicator Start                                                                           |                                                        
//+-------------------------------------------------------------------------------------------+ 
int start()
   {
   //If indicator is "Off" deinitialize only once, not every tick.  
   if (!Indicator_On)    
      {
      if (!FLAG_deinit) {deinit(); FLAG_deinit = true;}
      return(0);
      }

   //Otherwise indicator is "On", so proceed.   
   deinit(); FLAG_deinit = false;
   
   //Count visible chart bars
   for(i = Bars-1-IndicatorCounted(); i >= 0; i--)        
      {          
      //Volume spread alculations 
      HiValue2 = 0;               
      Range = (High[i]-Low[i]);
      Value2 = Volume[i]*Range;                 
      for (n=i;n<i+Volume_Analysis_GoBack;n++)
         {
         tempv2 = Volume[n]*((High[n]-Low[n])); 
         if (tempv2 >= HiValue2) {HiValue2 = tempv2;}    
         }             

      //Get average Volume
      av = 0;
      for (j = i; j < (i+Volume_Averaging_Period); j++) av = av + Volume[j];
      av = av / Volume_Averaging_Period;
            
      //Determine candle color
      if(Value2 == HiValue2) {clr= 3;}
      else
         { 
         if (Volume[i] < av * Volume_Over_Average_Factor) {clr= 1;}
         else {clr= 2;}    
         }
      
      //Apply colors
		shift1 = iBarShift(NULL,0,Time[i]);			 	          
      if (clr==2)
         {
         Buffer1[i]=iClose(NULL,0,shift1);
         Buffer2[i]=iOpen(NULL,0,shift1);      
         }
      else if (clr==3)
         {
         Buffer3[i]=iClose(NULL,0,shift1);
         Buffer4[i]=iOpen(NULL,0,shift1);       
         }                   
      }      
     
   return(0);
   }

//+-------------------------------------------------------------------------------------------+
//| Indicator End                                                                             |                                                        
//+-------------------------------------------------------------------------------------------+    